# 🎛️ yamlpars
[![Documentation Status](https://readthedocs.org/projects/yamlpars/badge/?version=latest)](https://yamlpars.readthedocs.io/en/latest/?badge=latest)
[![PyPI](https://img.shields.io/pypi/v/yamlpars)](https://pypi.org/project/yamlpars/)
[![License: MIT](https://img.shields.io/badge/license-MIT-brightgreen)](https://github.com/matpompili/yamlpars/blob/main/LICENSE)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Tests](https://github.com/matpompili/yamlpars/actions/workflows/python-package.yml/badge.svg)](https://github.com/matpompili/yamlpars/actions/workflows/python-package.yml)

With yamlpars you can save configurations and parameters to YAML files, in a structured and easy-to use way.

Check out the [documentation](https://yamlpars.readthedocs.io/en/latest/).